==> mitm_tooling-0.4.9-py3-none-any.whl: mitm_tooling/transformation/superset/from_sql.py <==
from uuid import UUID

from mitm_tooling.definition import MITM
from mitm_tooling.extraction.sql.data_models import DBMetaInfo
from mitm_tooling.extraction.sql.data_models.db_meta import DBMetaInfoBase
from mitm_tooling.extraction.sql.db import connect_and_reflect
from .asset_bundles import SupersetDatasourceBundle, \
    SupersetMitMDatasetBundle
from .common import DBConnectionInfo
from .common import _mk_engine, SQLiteFileOrEngine
from .definitions import DatasourceIdentifierMap
from .definitions.mitm_dataset import MitMDatasetIdentifier
from .factories.database import mk_database
from .factories.dataset import mk_dataset
from .factories.mitm_dataset import mk_mitm_dataset


def db_meta_into_superset_datasource_bundle(db_meta: DBMetaInfoBase,
                                            db_conn_info: DBConnectionInfo,
                                            database_uuid: UUID | None = None,
                                            ds_id_map: DatasourceIdentifierMap | None = None) -> SupersetDatasourceBundle:
    sqlalchemy_uri = db_conn_info.sql_alchemy_uri
    db_name = db_conn_info.db_name
    dialect = db_conn_info.dialect_cls()

    database = mk_database(name=db_name, sqlalchemy_uri=sqlalchemy_uri, uniquify_name=True, uuid=database_uuid)

    database_uuid = database.uuid
    datasets = []
    ds_id_map = ds_id_map or {}

    def ds_uuid(tn: str) -> UUID | None:
        if (ds_id := ds_id_map.get(tn)) is not None:
            return ds_id.uuid

    for schema_name, schema_tables in db_meta.db_structure.items():
        for table_name, tm in schema_tables.items():
            datasets.append(mk_dataset(tm, database_uuid, dialect=dialect, uuid=ds_uuid(table_name)))

    return SupersetDatasourceBundle(database=database, datasets=datasets)


def db_meta_into_mitm_dataset_bundle(db_meta: DBMetaInfoBase,
                                     db_conn_info: DBConnectionInfo,
                                     dataset_identifier: MitMDatasetIdentifier,
                                     mitm: MITM,
                                     database_uuid: UUID | None = None,
                                     ds_id_map: DatasourceIdentifierMap | None = None) -> SupersetMitMDatasetBundle:
    datasource_bundle = db_meta_into_superset_datasource_bundle(db_meta,
                                                                db_conn_info,
                                                                database_uuid=database_uuid,
                                                                ds_id_map=ds_id_map)
    mitm_dataset = mk_mitm_dataset(dataset_identifier.dataset_name, mitm, uuid=dataset_identifier.uuid,
                                   database_uuid=datasource_bundle.database_uuid,
                                   table_uuids=datasource_bundle.dataset_uuids)
    return SupersetMitMDatasetBundle(mitm_dataset=mitm_dataset, datasource_bundle=datasource_bundle)


def db_into_superset_datasource_bundle(arg: SQLiteFileOrEngine,
                                       db_conn_info: DBConnectionInfo,
                                       database_uuid: UUID | None = None,
                                       ds_id_map: DatasourceIdentifierMap | None = None) -> SupersetDatasourceBundle:
    engine = _mk_engine(arg)

    meta, _ = connect_and_reflect(engine, allowed_schemas=[db_conn_info.schema_name])
    db_meta = DBMetaInfo.from_sa_meta(meta, default_schema=db_conn_info.schema_name)

    return db_meta_into_superset_datasource_bundle(db_meta,
                                                   db_conn_info,
                                                   database_uuid=database_uuid,
                                                   ds_id_map=ds_id_map)


def db_into_mitm_dataset_bundle(arg: SQLiteFileOrEngine,
                                db_conn_info: DBConnectionInfo,
                                dataset_identifier: MitMDatasetIdentifier,
                                mitm: MITM,
                                database_uuid: UUID | None = None,
                                ds_id_map: DatasourceIdentifierMap | None = None) -> SupersetMitMDatasetBundle:
    datasource_bundle = db_into_superset_datasource_bundle(arg,
                                                           db_conn_info,
                                                           database_uuid=database_uuid,
                                                           ds_id_map=ds_id_map)
    mitm_dataset = mk_mitm_dataset(dataset_identifier.dataset_name, mitm, uuid=dataset_identifier.uuid,
                                   database_uuid=datasource_bundle.database_uuid,
                                   table_uuids=datasource_bundle.dataset_uuids)
    return SupersetMitMDatasetBundle(mitm_dataset=mitm_dataset, datasource_bundle=datasource_bundle)

==> mitm_tooling-0.5.0-py3-none-any.whl: mitm_tooling/transformation/superset/from_sql.py <==
from uuid import UUID

from mitm_tooling.extraction.sql.data_models import DBMetaInfo
from mitm_tooling.extraction.sql.data_models.db_meta import DBMetaInfoBase
from mitm_tooling.extraction.sql.db import connect_and_reflect
from .asset_bundles import SupersetDatasourceBundle, \
    SupersetMitMDatasetBundle
from .asset_bundles.identifier import DatasourceIdentifierBundle, MitMDatasetIdentifierBundle
from .common import DBConnectionInfo, MitMDatasetInfo
from .common import _mk_engine, SQLiteFileOrEngine
from .factories.database import mk_database
from .factories.dataset import mk_dataset
from .factories.mitm_dataset import mk_mitm_dataset


def db_meta_into_superset_datasource_bundle(db_meta: DBMetaInfoBase,
                                            db_conn_info: DBConnectionInfo,
                                            identifiers: DatasourceIdentifierBundle | None = None) -> SupersetDatasourceBundle:
    sqlalchemy_uri = db_conn_info.sql_alchemy_uri
    db_name = db_conn_info.db_name
    dialect = db_conn_info.dialect_cls()
    identifiers = identifiers or DatasourceIdentifierBundle()

    database = mk_database(name=db_name,
                           sqlalchemy_uri=sqlalchemy_uri,
                           uniquify_name=True,
                           uuid=identifiers.database_uuid)

    database_uuid = database.uuid
    datasets = []
    ds_id_map = identifiers.ds_id_map or {}

    def ds_uuid(tn: str) -> UUID | None:
        if (ds_id := ds_id_map.get(tn)) is not None:
            return ds_id.uuid

    for schema_name, schema_tables in db_meta.db_structure.items():
        for table_name, tm in schema_tables.items():
            datasets.append(mk_dataset(tm, database_uuid, dialect=dialect, uuid=ds_uuid(table_name)))

    return SupersetDatasourceBundle(database=database, datasets=datasets)


def db_meta_into_mitm_dataset_bundle(db_meta: DBMetaInfoBase,
                                     db_conn_info: DBConnectionInfo,
                                     dataset_info: MitMDatasetInfo,
                                     identifiers: MitMDatasetIdentifierBundle | None = None) -> SupersetMitMDatasetBundle:
    identifiers = identifiers or MitMDatasetIdentifierBundle()


    datasource_bundle = db_meta_into_superset_datasource_bundle(db_meta,
                                                                db_conn_info,
                                                                identifiers)

    mitm_dataset = mk_mitm_dataset(dataset_info.dataset_name, dataset_info.mitm,
                                   uuid=identifiers.mitm_dataset_uuid,
                                   database_uuid=datasource_bundle.database_uuid,
                                   table_uuids=datasource_bundle.dataset_uuids)
    return SupersetMitMDatasetBundle(mitm_dataset=mitm_dataset, datasource_bundle=datasource_bundle)


def db_into_superset_datasource_bundle(arg: SQLiteFileOrEngine,
                                       db_conn_info: DBConnectionInfo,
                                       identifiers: DatasourceIdentifierBundle | None = None) -> SupersetDatasourceBundle:
    identifiers = identifiers or DatasourceIdentifierBundle()

    engine = _mk_engine(arg)

    meta, _ = connect_and_reflect(engine, allowed_schemas=[db_conn_info.schema_name])
    db_meta = DBMetaInfo.from_sa_meta(meta, default_schema=db_conn_info.schema_name)

    return db_meta_into_superset_datasource_bundle(db_meta,
                                                   db_conn_info,
                                                   identifiers)


def db_into_mitm_dataset_bundle(arg: SQLiteFileOrEngine,
                                db_conn_info: DBConnectionInfo,
                                dataset_info: MitMDatasetInfo,
                                identifiers: MitMDatasetIdentifierBundle | None = None) -> SupersetMitMDatasetBundle:
    identifiers = identifiers or MitMDatasetIdentifierBundle()

    datasource_bundle = db_into_superset_datasource_bundle(arg,
                                                           db_conn_info,
                                                           identifiers)
    mitm_dataset = mk_mitm_dataset(dataset_info.dataset_name, dataset_info.mitm, uuid=identifiers.mitm_dataset_uuid,
                                   database_uuid=datasource_bundle.database_uuid,
                                   table_uuids=datasource_bundle.dataset_uuids)
    return SupersetMitMDatasetBundle(mitm_dataset=mitm_dataset, datasource_bundle=datasource_bundle)
